@@ -1,4 +1,3 @@
-
 analyze <- function(model, data, package = "lavaan", miss = NULL, 
     aux = NULL, group = NULL, mxMixture = FALSE, ...) {
 	mc <- match.call()
@@ -50,7 +49,7 @@ analyzeSimSem <- function(model, data, package = "lavaan", miss = NULL,
 				}
 			}
 		}
-        Output <- runMI(model@pt, data, m = miss@m, miArgs=miArgs, chi=miss@chi, miPackage=miss@package, fun="lavaan", ...)
+        Output <- semTools::runMI(model@pt, data, m = miss@m, miArgs=miArgs, chi=miss@chi, miPackage=miss@package, fun="lavaan", ...)
     } else {
 		# If the missing argument is not specified and data have NAs, the default is fiml.
 		if(is.null(args$missing)) {
@@ -68,12 +67,13 @@ analyzeSimSem <- function(model, data, package = "lavaan", miss = NULL,
 			attribute <- list(model=model@pt, aux = aux, data = data, group = groupLab, 
                 model.type = model@modelType, missing = missing, fun = "lavaan")
 			attribute <- c(attribute, args)
-			Output <- do.call(auxiliary, attribute)
+			Output <- do.call(semTools::auxiliary, attribute)
         } else {
+			#library(lavaan)
 			attribute <- list(model=model@pt, data = data, group = groupLab, model.type = model@modelType, 
                 missing = missing)
 			attribute <- c(attribute, args)
-			Output <- do.call(lavaan, attribute)
+			Output <- do.call(lavaan::lavaan, attribute)
         }
     }
     return(Output)
@@ -81,11 +81,12 @@ analyzeSimSem <- function(model, data, package = "lavaan", miss = NULL,
 
 # To be used internally
 anal <- function(model, data, package = "lavaan", ...) {
+	#library(lavaan)
 	groupLab <- model@groupLab
 	if(length(unique(model@pt$group[model@pt$op %in% c("=~", "~~", "~", "~1", "|")])) == 1) {
 		groupLab <- NULL
 	}
-    Output <- lavaan(model@pt, data = data, group = groupLab, model.type = model@modelType, 
+    Output <- lavaan::lavaan(model@pt, data = data, group = groupLab, model.type = model@modelType, 
         ...)
     return(Output)
 } 
@@ -119,14 +120,11 @@ analyzeLavaan <- function(args, fun = "lavaan", miss = NULL, aux = NULL) {
     } else {
 		# If the missing argument is not specified and data have NAs, the default is fiml.
 		if(is.null(args$missing)) {
-			missing <- "default"
-			if (any(is.na(args$data))) {
-				missing <- "fiml"
+			args$missing <- "default"
+			if ((!is.null(miss) && (miss@m == 0)) || any(is.na(args$data))) {
+				args$missing <- "fiml"
 			}
-		} else {
-			missing <- args$missing
-			args$missing <- NULL
-		}
+		} 
         if (!is.null(aux)) {
             library(semTools)	
 			if(is.numeric(aux)) aux <- colnames(model$data)[aux]
@@ -138,4 +136,4 @@ analyzeLavaan <- function(args, fun = "lavaan", miss = NULL, aux = NULL) {
         }
     }
 	return(Output)
-}
\ No newline at end of file
+}
